@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -165,7 +137,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
                         try {
                             final int accountId = mailAccount.getId();
                             mailAccess = MailAccess.getInstance(getSession(), accountId);
-                            mailAccess.connect();
+                            mailAccess.connect(true, access.isDebug());
                             final String fn = UnifiedInboxUtility.determineAccountFullName(mailAccess, fullName);
                             // Check if denoted account has such a default folder
                             if (fn == null) {
@@ -230,7 +202,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         try {
             final int accountId = fa.getAccountId();
             mailAccess = MailAccess.getInstance(session, accountId);
-            mailAccess.connect();
+            mailAccess.connect(true, access.isDebug());
             // Get account's messages
             final String fn = fa.getFullname();
 
@@ -285,7 +257,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
                         try {
                             final int accountId = mailAccount.getId();
                             mailAccess = MailAccess.getInstance(getSession(), accountId);
-                            mailAccess.connect();
+                            mailAccess.connect(true, access.isDebug());
                             final String fn = UnifiedInboxUtility.determineAccountFullName(mailAccess, fullName);
                             // Check if denoted account has such a default folder
                             if (fn == null) {
@@ -347,7 +319,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         try {
             final int accountId = fa.getAccountId();
             mailAccess = MailAccess.getInstance(session, accountId);
-            mailAccess.connect();
+            mailAccess.connect(true, access.isDebug());
             // Get account's messages
             IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
 
@@ -392,7 +364,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
                         try {
                             final int accountId = mailAccount.getId();
                             mailAccess = MailAccess.getInstance(getSession(), accountId);
-                            mailAccess.connect();
+                            mailAccess.connect(true, access.isDebug());
                             final String fn = UnifiedInboxUtility.determineAccountFullName(mailAccess, fullName);
                             // Check if denoted account has such a default folder
                             if (fn == null) {
@@ -438,7 +410,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         try {
             final int accountId = fa.getAccountId();
             mailAccess = MailAccess.getInstance(session, accountId);
-            mailAccess.connect();
+            mailAccess.connect(true, access.isDebug());
             // Get account's messages
 
             IMailFolderStorageEnhanced storageEnhanced = mailAccess.getFolderStorage().supports(IMailFolderStorageEnhanced.class);
@@ -472,7 +444,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
                         try {
                             final int accountId = mailAccount.getId();
                             mailAccess = MailAccess.getInstance(getSession(), accountId);
-                            mailAccess.connect();
+                            mailAccess.connect(true, access.isDebug());
                             final String fn = UnifiedInboxUtility.determineAccountFullName(mailAccess, fullName);
                             // Check if denoted account has such a default folder
                             if (fn == null) {
@@ -519,7 +491,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         try {
             final int accountId = fa.getAccountId();
             mailAccess = MailAccess.getInstance(session, accountId);
-            mailAccess.connect();
+            mailAccess.connect(true, access.isDebug());
             // Get account's messages
 
             IMailFolderStorageEnhanced storageEnhanced = mailAccess.getFolderStorage().supports(IMailFolderStorageEnhanced.class);
@@ -554,7 +526,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
                         try {
                             final int accountId = mailAccount.getId();
                             mailAccess = MailAccess.getInstance(getSession(), accountId);
-                            mailAccess.connect();
+                            mailAccess.connect(true, access.isDebug());
                             final String fn = UnifiedInboxUtility.determineAccountFullName(mailAccess, fullName);
                             // Check if denoted account has such a default folder
                             if (fn == null) {
@@ -600,7 +572,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         try {
             final int accountId = fa.getAccountId();
             mailAccess = MailAccess.getInstance(session, accountId);
-            mailAccess.connect();
+            mailAccess.connect(true, access.isDebug());
             // Get account's messages
 
             IMailFolderStorageEnhanced storageEnhanced = mailAccess.getFolderStorage().supports(IMailFolderStorageEnhanced.class);
@@ -635,7 +607,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         MailAccess<?, ?> mailAccess = null;
         try {
             mailAccess = MailAccess.getInstance(session, fa.getAccountId());
-            mailAccess.connect();
+            mailAccess.connect(true, access.isDebug());
             return mailAccess.getFolderStorage().exists(fa.getFullname());
         } finally {
             if (null != mailAccess) {
@@ -662,7 +634,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
             MailAccess<?, ?> mailAccess = null;
             try {
                 mailAccess = MailAccess.getInstance(session, nestedAccountId);
-                mailAccess.connect();
+                mailAccess.connect(true, access.isDebug());
                 final String nestedFullname = fa.getFullname();
                 final MailFolder mailFolder = mailAccess.getFolderStorage().getFolder(nestedFullname);
                 final String startingKnownFullname = getStartingKnownFullname(fullname);
@@ -847,7 +819,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
                     MailAccess<?, ?> mailAccess = null;
                     try {
                         mailAccess = MailAccess.getInstance(getSession(), mailAccount.getId());
-                        mailAccess.connect();
+                        mailAccess.connect(true, access.isDebug());
                         final String accountFullname = UnifiedInboxUtility.determineAccountFullName(mailAccess, parentFullName);
                         // Check if account fullname is not null
                         if (null == accountFullname) {
@@ -958,7 +930,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
                         String fn = null;
                         try {
                             mailAccess = MailAccess.getInstance(getSession(), accountId);
-                            mailAccess.connect();
+                            mailAccess.connect(true, access.isDebug());
                             // Get real full name
                             fn = UnifiedInboxUtility.determineAccountFullName(mailAccess, fullName);
                             // Check if denoted account has such a default folder
@@ -999,7 +971,7 @@ public final class UnifiedInboxFolderStorage extends MailFolderStorage implement
         MailAccess<?, ?> mailAccess = null;
         try {
             mailAccess = MailAccess.getInstance(session, fa.getAccountId());
-            mailAccess.connect();
+            mailAccess.connect(true, access.isDebug());
             // Clear folder
             mailAccess.getFolderStorage().clearFolder(fullName, hardDelete);
         } finally {
